djangolive (Under development)
==============================

.. image:: https://readthedocs.org/projects/djangoiot/badge/?version=latest
    :target: https://djangolive.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. image:: https://travis-ci.org/Tomvictor/djangolive.svg?branch=master
    :target: https://travis-ci.org/Tomvictor/djangolive


Djangolive helps the Django to keep track of users.

For full documentation, visit `djangolive.readthedocs.io
<https://djangolive.readthedocs.io/en/latest/>`__.

Features
--------

- User activity tracking
- Track users in djnago admin

Installation
------------

Install djangolive by running::

    pip install djangolive


Contribute
----------

- Issue Tracker: github.com/tomvictor/djangolive/issues
- Source Code: github.com/tomvictor/djangolive

Support
-------

If you are having issues, please let raise issue on github.

License
-------

The project is licensed under the MIT license.
